@@ -1594,6 +1594,11 @@ cal_backend_wcap_finalize (GObject *object)
 			priv->timezones = NULL;
 		}
 
+		if (priv->default_zone) {
+			icaltimezone_free (priv->default_zone, 1);
+			priv->default_zone = NULL;
+		}
+
 		if (priv->objects) {
 			g_hash_table_foreach (priv->objects, (GHFunc) destroy_object_hash, NULL);
 			g_hash_table_destroy (priv->objects);
@@ -2216,22 +2221,36 @@ cal_backend_wcap_add_timezone (ECalBackendSync *backend, EDataCal *cal, const ch
 }
 
 static ECalBackendSyncStatus
-cal_backend_wcap_set_default_timezone (ECalBackendSync *backend, EDataCal *cal, const char *tzid)
+cal_backend_wcap_set_default_zone (ECalBackendSync *backend, EDataCal *cal, const char *tzobj)
 {
 	CalBackendWCAP *wcap = (CalBackendWCAP *) backend;
-	CalBackendWCAPPrivate *priv = wcap->priv;
+	CalBackendWCAPPrivate *priv;
+	icalcomponent *tz_comp;
+	icaltimezone *zone;
 
-	g_return_val_if_fail (tzid != NULL, GNOME_Evolution_Calendar_InvalidObject);
+	g_return_val_if_fail (tzobj != NULL, GNOME_Evolution_Calendar_InvalidObject);
 	g_return_val_if_fail (IS_CAL_BACKEND_WCAP (wcap), GNOME_Evolution_Calendar_OtherError);
 
-	d(printf("cal_backend_wcap_set_default_timezone(%p, %s)\n", backend, tzid));
+	d(printf("cal_backend_wcap_set_default_zone(%p, %s)\n", backend, tzobj));
+	printf("cal_backend_wcap_set_default_zone(%p, %s)\n", backend, tzobj);
 
-	priv->default_zone = icaltimezone_get_builtin_timezone_from_tzid (tzid);
+	priv = wcap->priv;
+	tz_comp = icalparser_parse_string (tzobj);
+	if (!tz_comp)
+		return GNOME_Evolution_Calendar_InvalidObject;
+
+	zone = icaltimezone_new ();
+	icaltimezone_set_component (zone, tz_comp);
+
+	if (priv->default_zone != NULL)
+		icaltimezone_free (priv->default_zone, 1);
+
+	priv->default_zone = zone;
 
 	if (priv->default_zone)
 		return GNOME_Evolution_Calendar_Success;
 
-	return GNOME_Evolution_Calendar_ObjectNotFound;
+	return GNOME_Evolution_Calendar_InvalidObject;
 }
 
 static ECalBackendSyncStatus
@@ -2627,7 +2646,7 @@ cal_backend_wcap_class_init (CalBackendWCAPClass *klass)
 	sync_class->get_object_list_sync = cal_backend_wcap_get_object_list;
 	sync_class->get_timezone_sync = cal_backend_wcap_get_timezone;
 	sync_class->add_timezone_sync = cal_backend_wcap_add_timezone;
-	sync_class->set_default_timezone_sync = cal_backend_wcap_set_default_timezone;
+	sync_class->set_default_zone_sync = cal_backend_wcap_set_default_zone;
 	sync_class->get_freebusy_sync = cal_backend_wcap_get_freebusy;
 	sync_class->get_changes_sync = cal_backend_wcap_get_changes;
 	sync_class->create_object_sync = cal_backend_wcap_create_object;
